#!/bin/sh
#
# scas       Starting, stopping and restarting the scas daemon.
#  
# Author:    Oscar Koeroo
#
# chkconfig: 2345 99 01
# description: Starts and stops SCAS daemon



prog="scas"
fullprog='/opt/glite/sbin/scas'
configfile='/opt/glite/etc/scas.conf'
lockfile="/var/lock/subsys/scas"
nonprivaccount='scas'


# Source function library
. /etc/rc.d/init.d/functions


start() {
    echo -n "Starting SCAS: "

        # Check if there should be a SCAS instance running
    if [ -f $lockfile ]; then
                # SCAS still running?
        scaspid=`pidofproc $fullprog`
        if [ -z "$scaspid" ]; then
            echo -n "Removing stale lockfile"
            rm -f $lockfile
        else
            # SCAS already running
            success "Looks like there's still another SCAS daemon running."
            echo
            exit $?
        fi
    fi
    # Starting SCAS daemon now.
    daemon --user $nonprivaccount $fullprog --conf $configfile
    touch $lockfile
    echo_success
    echo
}


stop() {
    # Stopping SCAS
    echo -n "Stopping SCAS:"
    if [ -f $lockfile ]; then
        # Killing SCAS now.
        killproc $fullprog
        rm -f $lockfile
        echo_success
        echo
    else
        # No SCAS running, nothing to kill
        failure "No SCAS is running."
        echo
        exit $?
    fi
}


condrestartstuff() {
    touch $lockfile
}


# See how we were called.
case "$1" in
    start)
        start
        ;;
    stop)
        stop
        ;;
    condrestart)
        echo "Conditionally restarting SCAS."
        condrestartstuff
        stop
        start
        ;;
    restart)
        echo "Restarting SCAS."
        stop
        start
        ;;
    status)
        status $fullprog
        ;;
    *)
        echo "Usage: $0 {start|stop|restart|condrestart|status}"
        exit 1
esac

exit 0
